==> ejc-sddjsorg-api-3.0.0-20211021.075752-43-sources.jar: com/ejianc/business/sddjsorg/vo/ShareholderDecisionVO.java <==
package com.ejianc.business.sddjsorg.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;
import java.util.List;

/**
 * 股东决策
 *
 * @author CJ
 * @Description: 股东决策
 * @date 2021/10/20 9:33
 */
public class ShareholderDecisionVO extends BaseVO {

    private static final long serialVersionUID = -9063991720095877064L;

    /**
     * 单据录入人组织Id
     */
    private Long orgId;

    /**
     * 单据录入人组织名称
     */
    private String orgName;

    /**
     * 公司编码
     */
    private String sddjsOrgCode;

    /**
     * 公司名称
     */
    private String sddjsOrgName;

    /**
     * 公司id
     */
    private Long sddjsOrgId;

    /**
     * 公司注册性质id
     */
    private Long orgNatureId;

    /**
     * 公司注册性质
     */
    private String orgNatureName;

    /**
     * 决策内容
     */
    private String decisionContent;

    /**
     * 承办人Id
     */
    private Long undertabkeEmployeeId;

    /**
     * 承办人名称
     */
    private String undertakeEmployeeName;

    /**
     * 承办部门id
     */
    private Long undertakeDeptId;

    /**
     * 承办部门名称
     */
    private String undertakeDeptName;

    /**
     * 主要事项描述
     */
    private String mainMattersDesc;

    /**
     * 需公司决策事宜
     */
    private String mattersDecideByOrg;

    /**
     * 备注
     */
    private String remark;

    /**
     * 档案资料
     */
    List<ShareholderDecisionFileVO> docFiles;

    /**
     * 单据状态
     */
    private Integer billState;

    /**
     * 提交日期
     */
    private Date commitDate;

    /**
     * 提交人名称
     */
    private String commitUserName;

    /**
     * 提交人账号
     */
    private String commitUserCode;

    /**
     * 生效日期
     */
    private Date effectiveDate;

    /**
     * 创建人名称
     */
    private String createUserName;

    /**
     * 修改人名称
     */
    private String modifyUserName;

    /**
     * 单据编码
     */
    private String billCode;

    private String billStateName;

    private String createTimeStr;

    public String getCreateTimeStr() {
        return createTimeStr;
    }

    public void setCreateTimeStr(String createTimeStr) {
        this.createTimeStr = createTimeStr;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getSddjsOrgCode() {
        return sddjsOrgCode;
    }

    public void setSddjsOrgCode(String sddjsOrgCode) {
        this.sddjsOrgCode = sddjsOrgCode;
    }

    public String getSddjsOrgName() {
        return sddjsOrgName;
    }

    public void setSddjsOrgName(String sddjsOrgName) {
        this.sddjsOrgName = sddjsOrgName;
    }

    public Long getSddjsOrgId() {
        return sddjsOrgId;
    }

    @ReferDeserialTransfer
    public void setSddjsOrgId(Long sddjsOrgId) {
        this.sddjsOrgId = sddjsOrgId;
    }

    public Long getOrgNatureId() {
        return orgNatureId;
    }

    @ReferDeserialTransfer
    public void setOrgNatureId(Long orgNatureId) {
        this.orgNatureId = orgNatureId;
    }

    public String getOrgNatureName() {
        return orgNatureName;
    }

    public void setOrgNatureName(String orgNatureName) {
        this.orgNatureName = orgNatureName;
    }

    public String getDecisionContent() {
        return decisionContent;
    }

    public void setDecisionContent(String decisionContent) {
        this.decisionContent = decisionContent;
    }

    public Long getUndertabkeEmployeeId() {
        return undertabkeEmployeeId;
    }

    @ReferDeserialTransfer
    public void setUndertabkeEmployeeId(Long undertabkeEmployeeId) {
        this.undertabkeEmployeeId = undertabkeEmployeeId;
    }

    public String getUndertakeEmployeeName() {
        return undertakeEmployeeName;
    }

    public void setUndertakeEmployeeName(String undertakeEmployeeName) {
        this.undertakeEmployeeName = undertakeEmployeeName;
    }

    public Long getUndertakeDeptId() {
        return undertakeDeptId;
    }

    @ReferDeserialTransfer
    public void setUndertakeDeptId(Long undertakeDeptId) {
        this.undertakeDeptId = undertakeDeptId;
    }

    public String getUndertakeDeptName() {
        return undertakeDeptName;
    }

    public void setUndertakeDeptName(String undertakeDeptName) {
        this.undertakeDeptName = undertakeDeptName;
    }

    public String getMainMattersDesc() {
        return mainMattersDesc;
    }

    public void setMainMattersDesc(String mainMattersDesc) {
        this.mainMattersDesc = mainMattersDesc;
    }

    public String getMattersDecideByOrg() {
        return mattersDecideByOrg;
    }

    public void setMattersDecideByOrg(String mattersDecideByOrg) {
        this.mattersDecideByOrg = mattersDecideByOrg;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public List<ShareholderDecisionFileVO> getDocFiles() {
        return docFiles;
    }

    public void setDocFiles(List<ShareholderDecisionFileVO> docFiles) {
        this.docFiles = docFiles;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }

    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }

    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }

    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }

    @Override
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public String getModifyUserName() {
        return modifyUserName;
    }

    public void setModifyUserName(String modifyUserName) {
        this.modifyUserName = modifyUserName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
}

==> ejc-sddjsorg-api-3.0.0-20211027.094922-106-sources.jar: com/ejianc/business/sddjsorg/vo/ShareholderDecisionVO.java <==
package com.ejianc.business.sddjsorg.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;
import java.util.List;

/**
 * 股东决策
 *
 * @author CJ
 * @Description: 股东决策
 * @date 2021/10/20 9:33
 */
public class ShareholderDecisionVO extends BaseVO {

    private static final long serialVersionUID = -9063991720095877064L;

    /**
     * 单据录入人组织Id
     */
    private Long orgId;

    /**
     * 单据录入人组织名称
     */
    private String orgName;

    /**
     * 公司编码
     */
    private String sddjsOrgCode;

    /**
     * 公司名称
     */
    private String sddjsOrgName;

    /**
     * 公司id
     */
    private Long sddjsOrgId;

    /**
     * 公司注册性质id
     */
    private Long orgNatureId;

    /**
     * 公司注册性质
     */
    private String orgNatureName;

    /**
     * 决策内容
     */
    private String decisionContent;

    /**
     * 承办人Id
     */
    private Long undertakeEmployeeId;

    /**
     * 承办人名称
     */
    private String undertakeEmployeeName;

    /**
     * 承办部门id
     */
    private Long undertakeDeptId;

    /**
     * 承办部门名称
     */
    private String undertakeDeptName;

    /**
     * 主要事项描述
     */
    private String mainMattersDesc;

    /**
     * 需公司决策事宜
     */
    private String mattersDecideByOrg;

    /**
     * 备注
     */
    private String remark;

    /**
     * 档案资料
     */
    List<ShareholderDecisionFileVO> docFiles;

    /**
     * 单据状态
     */
    private Integer billState;

    /**
     * 提交日期
     */
    private Date commitDate;

    /**
     * 提交人名称
     */
    private String commitUserName;

    /**
     * 提交人账号
     */
    private String commitUserCode;

    /**
     * 生效日期
     */
    private Date effectiveDate;

    /**
     * 创建人名称
     */
    private String createUserName;

    /**
     * 修改人名称
     */
    private String modifyUserName;

    /**
     * 单据编码
     */
    private String billCode;

    private String billStateName;

    private String createTimeStr;

    public String getCreateTimeStr() {
        return createTimeStr;
    }

    public void setCreateTimeStr(String createTimeStr) {
        this.createTimeStr = createTimeStr;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getSddjsOrgCode() {
        return sddjsOrgCode;
    }

    public void setSddjsOrgCode(String sddjsOrgCode) {
        this.sddjsOrgCode = sddjsOrgCode;
    }

    public String getSddjsOrgName() {
        return sddjsOrgName;
    }

    public void setSddjsOrgName(String sddjsOrgName) {
        this.sddjsOrgName = sddjsOrgName;
    }

    public Long getSddjsOrgId() {
        return sddjsOrgId;
    }

    @ReferDeserialTransfer
    public void setSddjsOrgId(Long sddjsOrgId) {
        this.sddjsOrgId = sddjsOrgId;
    }

    public Long getOrgNatureId() {
        return orgNatureId;
    }

    @ReferDeserialTransfer
    public void setOrgNatureId(Long orgNatureId) {
        this.orgNatureId = orgNatureId;
    }

    public String getOrgNatureName() {
        return orgNatureName;
    }

    public void setOrgNatureName(String orgNatureName) {
        this.orgNatureName = orgNatureName;
    }

    public String getDecisionContent() {
        return decisionContent;
    }

    public void setDecisionContent(String decisionContent) {
        this.decisionContent = decisionContent;
    }

    public Long getUndertakeEmployeeId() {
        return undertakeEmployeeId;
    }

    @ReferDeserialTransfer
    public void setUndertakeEmployeeId(Long undertakeEmployeeId) {
        this.undertakeEmployeeId = undertakeEmployeeId;
    }

    public String getUndertakeEmployeeName() {
        return undertakeEmployeeName;
    }

    public void setUndertakeEmployeeName(String undertakeEmployeeName) {
        this.undertakeEmployeeName = undertakeEmployeeName;
    }

    public Long getUndertakeDeptId() {
        return undertakeDeptId;
    }

    @ReferDeserialTransfer
    public void setUndertakeDeptId(Long undertakeDeptId) {
        this.undertakeDeptId = undertakeDeptId;
    }

    public String getUndertakeDeptName() {
        return undertakeDeptName;
    }

    public void setUndertakeDeptName(String undertakeDeptName) {
        this.undertakeDeptName = undertakeDeptName;
    }

    public String getMainMattersDesc() {
        return mainMattersDesc;
    }

    public void setMainMattersDesc(String mainMattersDesc) {
        this.mainMattersDesc = mainMattersDesc;
    }

    public String getMattersDecideByOrg() {
        return mattersDecideByOrg;
    }

    public void setMattersDecideByOrg(String mattersDecideByOrg) {
        this.mattersDecideByOrg = mattersDecideByOrg;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public List<ShareholderDecisionFileVO> getDocFiles() {
        return docFiles;
    }

    public void setDocFiles(List<ShareholderDecisionFileVO> docFiles) {
        this.docFiles = docFiles;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Date getCommitDate() {
        return commitDate;
    }

    public void setCommitDate(Date commitDate) {
        this.commitDate = commitDate;
    }

    public String getCommitUserName() {
        return commitUserName;
    }

    public void setCommitUserName(String commitUserName) {
        this.commitUserName = commitUserName;
    }

    public String getCommitUserCode() {
        return commitUserCode;
    }

    public void setCommitUserCode(String commitUserCode) {
        this.commitUserCode = commitUserCode;
    }

    public Date getEffectiveDate() {
        return effectiveDate;
    }

    public void setEffectiveDate(Date effectiveDate) {
        this.effectiveDate = effectiveDate;
    }

    @Override
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public String getModifyUserName() {
        return modifyUserName;
    }

    public void setModifyUserName(String modifyUserName) {
        this.modifyUserName = modifyUserName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
}
